==> pycopy-ast-2.0.tar.gz: pycopy-ast-2.0/ast/__init__.py <==
# (c) 2019 Paul Sokolovsky. MIT license.
from .types import *


def dump_to(t, file):
    if isinstance(t, AST):
        file.write(type(t).__name__)
        file.write("(")
        comma = False
        for k in t._fields:
            if k.startswith("_"):
                continue
            res = ""
            if comma:
                res += ", "
            res += k + "="
            file.write(res)
            dump_to(getattr(t, k, None), file)
            comma = True
        file.write(")")
    elif isinstance(t, list):
        file.write("[")
        comma = False
        for v in t:
            if comma:
                file.write(", ")
            dump_to(v, file)
            comma = True
        file.write("]")
    else:
        file.write(repr(t))


def dump(t):
    import io
    buf = io.StringIO()
    dump_to(t, buf)
    return buf.getvalue()


def iter_fields(t):
    for k in t._fields:
        if k.startswith("_"):
            continue
        yield (k, getattr(t, k, None))


def parse_stream(stream, filename="<unknown>", mode="exec"):
    import utokenize as tokenize
    from . import parser
    tstream = tokenize.tokenize(stream.readline)
    p = parser.Parser(tstream)
    p.match(tokenize.ENCODING)
    if mode == "exec":
        t = p.match_mod()
    elif mode == "eval":
        t = Expression(body=p.require_expr())
    elif mode == "single":
        t = Interactive(body=p.match_stmt())
    else:
        raise ValueError
    return t


def parse(source, filename="<unknown>", mode="exec"):
    import io
    return parse_stream(io.StringIO(source), filename, mode)

==> pycopy-ast-2.2.1.tar.gz: pycopy-ast-2.2.1/ast/__init__.py <==
# (c) 2019 Paul Sokolovsky. MIT license.
from .types import *


def dump_to_stream(t, file):
    if isinstance(t, AST):
        file.write(type(t).__name__)
        file.write("(")
        comma = False
        for k in t._fields:
            if k.startswith("_"):
                continue
            res = ""
            if comma:
                res += ", "
            res += k + "="
            file.write(res)
            dump_to_stream(getattr(t, k, None), file)
            comma = True
        file.write(")")
    elif isinstance(t, list):
        file.write("[")
        comma = False
        for v in t:
            if comma:
                file.write(", ")
            dump_to_stream(v, file)
            comma = True
        file.write("]")
    else:
        file.write(repr(t))


def dump(t):
    import io
    buf = io.StringIO()
    dump_to_stream(t, buf)
    return buf.getvalue()


def iter_fields(t):
    for k in t._fields:
        if k.startswith("_"):
            continue
        yield (k, getattr(t, k, None))


def parse_stream(stream, filename="<unknown>", mode="exec"):
    import utokenize as tokenize
    from . import parser
    tstream = tokenize.tokenize(stream.readline)
    p = parser.Parser(tstream)
    p.match(tokenize.ENCODING)
    if mode == "exec":
        t = p.match_mod()
    elif mode == "eval":
        t = Expression(body=p.require_expr())
    elif mode == "single":
        t = Interactive(body=p.match_stmt())
    else:
        raise ValueError
    return t


def parse(source, filename="<unknown>", mode="exec"):
    import io
    return parse_stream(io.StringIO(source), filename, mode)
